@@ -1,6 +1,7 @@
 #' Number of cut-points for binning
 #'
-#' This parameter controls how many bins are used when discretizing predictors.
+#' This parameter controls how many bins are used when discretizing predictors. 
+#' Used in `recipes::step_discretize()` and `embed::step_discretize_xgb()`.
 #'
 #' @inheritParams Laplace
 #' @examples
@@ -12,7 +13,6 @@ num_breaks <- function(range = c(2L, 10L), trans = NULL) {
     range = range,
     inclusive = c(TRUE, TRUE),
     trans = trans,
-    default = 4,
     label = c(num_breaks = "Number of Cut Points"),
     finalize = NULL
   )
