@@ -1,6 +1,6 @@
 #' Text hashing parameters
 #'
-#' Used in `textrecipes::step_texthash()`.
+#' Used in `textrecipes::step_texthash()` and `textrecipes::step_dummy_hash()`.
 #'
 #' @inheritParams Laplace
 #' @param values	A vector of possible values (TRUE or FALSE).
@@ -9,7 +9,7 @@
 #' signed_hash()
 #' @export
 #' @rdname texthash
-num_hash <- function(range = c(8L, 12L), trans = log2_trans()) {
+num_hash <- function(range = c(8L, 12L), trans = transform_log2()) {
   new_quant_param(
     type = "integer",
     range = range,
@@ -30,4 +30,3 @@ signed_hash <- function(values = c(TRUE, FALSE)) {
     finalize = NULL
   )
 }
-
