@@ -12,7 +12,7 @@
 #'   ensemble. In the latter case, this is equal to the number of boosting
 #'   iterations. (See `parsnip::rand_forest()` and `parsnip::boost_tree()`).
 #'
-#' * `min_n()`: The minimum number of data points in a node that are required
+#' * `min_n()`: The minimum number of data points in a node that is required
 #'   for the node to be split further. (See `parsnip::rand_forest()` and
 #'   `parsnip::boost_tree()`).
 #'
@@ -20,7 +20,7 @@
 #'   iteration of the modeling algorithm, such as stochastic gradient boosting.
 #'   (See `parsnip::boost_tree()`).
 #'
-#' * `sample_prop()`: The same as `sample_size()` but as a proporiton of the
+#' * `sample_prop()`: The same as `sample_size()` but as a proportion of the
 #'    total sample.
 #'
 #' * `loss_reduction()`: The reduction in the loss function required to split
@@ -96,7 +96,7 @@ sample_prop <- function(range = c(1/10, 1), trans = NULL) {
 
 #' @rdname trees
 #' @export
-loss_reduction <- function(range = c(-10, 1.5), trans = log10_trans()) {
+loss_reduction <- function(range = c(-10, 1.5), trans = transform_log10()) {
   new_quant_param(
     type = "double",
     range = range,
@@ -133,7 +133,7 @@ prune <- function(values = c(TRUE, FALSE)) {
 
 #' @export
 #' @rdname trees
-cost_complexity <- function(range = c(-10, -1), trans = log10_trans()) {
+cost_complexity <- function(range = c(-10, -1), trans = transform_log10()) {
   new_quant_param(
     type = "double",
     range = range,
