@@ -38,19 +38,24 @@ test_that("quantitative parameter object creation - bad args", {
   )
   expect_snapshot(
     error = TRUE,
-    new_quant_param("double", range = 1:2, inclusive = c(TRUE, NA))
+    new_quant_param("integer", range = 1:2, inclusive = c(TRUE, NA))
   )
   expect_snapshot(
     error = TRUE,
-    new_quant_param("double", range = 1:2, inclusive = c(TRUE, unknown()))
+    new_quant_param("integer", range = 1:2, inclusive = c(TRUE, unknown()))
   )
   expect_snapshot(
     error = TRUE,
-    new_quant_param("double", range = 1:2, inclusive = c(TRUE, TRUE), trans = log)
+    new_quant_param("integer", range = 1:2, inclusive = c(TRUE, TRUE), trans = log)
   )
   expect_snapshot(
     error = TRUE,
-    new_quant_param("double", range = 1:2, inclusive = c(TRUE, TRUE), values = 1:4)
+    new_quant_param("integer", range = 1:2, inclusive = c(TRUE, TRUE), values = 1:4)
+  )
+  expect_snapshot(
+    error = TRUE,
+    new_quant_param("integer", range = 1:2, inclusive = c(TRUE, TRUE),
+                    finalize = "not a function or NULL")
   )
 })
 
@@ -189,7 +194,7 @@ test_that("`values` is validated", {
 
 
 test_that("`default` arg is deprecated", {
-  expect_snapshot({
+  expect_snapshot(error = TRUE, {
     quant_param <- new_quant_param(
       type = "integer",
       default = 5L,
@@ -197,9 +202,7 @@ test_that("`default` arg is deprecated", {
       label = c(foo = "Foo")
     )
   })
-  expect_null(quant_param$default)
-
-  expect_snapshot({
+  expect_snapshot(error = TRUE, {
     qual_param <- new_qual_param(
       type = "logical",
       values = c(FALSE, TRUE),
@@ -207,5 +210,4 @@ test_that("`default` arg is deprecated", {
       label = c(foo = "Foo")
     )
   })
-  expect_null(qual_param$default)
 })
